@@ -9,13 +9,19 @@ class SerializerABC(abc.ABC):
         if "__type__" in obj:
             if obj["__type__"] == "uuid.UUID":
                 obj = UUID(obj["__value__"])
+            elif obj["__type__"] == "bytes":
+                obj = obj["__value__"].encode()
         return obj
 
     @staticmethod
     def encode(obj: Any) -> Any:
         if isinstance(obj, UUID):
             obj = {"__type__": "uuid.UUID", "__value__": str(obj)}
-        return obj
+            return obj
+        elif isinstance(obj, bytes):
+            obj = {"__type__": "bytes", "__value__": obj.decode()}
+            return obj
+        raise ValueError(f"Unknown type: {type(obj)}")
 
     @classmethod
     @abc.abstractmethod
