@@ -1,8 +1,9 @@
 import logging
 from typing import Generic, Type, TypeVar
 
-from .schema import CustomBaseModel
-from .serializer import Serializer, MsgpackSerializer
+from fastmicro.schema import CustomBaseModel
+from fastmicro.serializer import SerializerABC
+from fastmicro.serializer.json import Serializer
 
 logger = logging.getLogger(__name__)
 
@@ -14,11 +15,11 @@ class Topic(Generic[T]):
         self,
         name: str,
         schema: Type[T],
-        serializer: Type[Serializer] = MsgpackSerializer,
+        serializer: Type[SerializerABC] = Serializer,
     ):
         self.name = name
         self.schema = schema
-        self.serializer = serializer()
+        self.serializer = serializer
 
     async def serialize(self, message: T) -> bytes:
         return await self.serializer.serialize(message.dict(exclude_hidden=False))
